@@ -1,9 +1,9 @@
 import click
 from octohot.cli.sync import sync
 from octohot.cli.apply import apply
-from .git import git
-from .github import github
-from .regex import regex
+from octohot.cli.git import git
+from octohot.cli.github import github
+from octohot.cli.regex import regex
 
 
 @click.group()
